import React from 'react';
import PropTypes from 'prop-types';
import Close from './Close';

class Alert extends React.Component {

    render () {
        if (this.props.error === false && this.props.success === false) return null;
        const generateItems = (item) => {
            let items = [];
            item.forEach((item, key) =>
                items.push( <div key={key}>{item.text}</div>)
            )
            return items
        }
        let msg = '';
        if ( typeof this.props.data === 'string' ) {
            msg = this.props.data;
        } else if ( typeof this.props.data === 'object') {
            msg = generateItems(this.props.data)
        }

        return (
            <div ref={this.props.errorRef} style={{ ...{
                padding: '25px',
                position: 'relative',
                backgroundColor: this.props.success ? 'green' : this.props.error ? 'red' : '#fff',
                color: this.props.success || this.props.error ? '#fff' : '#000' }, ...this.props.style }}>
                {!this.props.hideClose ?
                    <Close style={{position: 'absolute', right: '15px', top: '15px'}} onClick={this.props.onClick} height='15px' width='15px' disableHover/>
                    :
                    null
                }
                {msg}
            </div>
        )
    }

};

Alert.defaultProps  = {
    onClick: function () {},
    errorRef: function () {},
    hideClose: false,
    error: false,
    success: false,
    data: [],
    style: {},
};

Alert.propTypes = {
    onClick: PropTypes.func,
    errorRef: PropTypes.func,
    error: PropTypes.bool,
    hideClose: PropTypes.bool.require,
    data: PropTypes.array,
    success: PropTypes.bool,
    style: PropTypes.object,
};

module.exports = Alert;
