import React from 'react';
import PropTypes from 'prop-types';
import {isTouch} from './utils';

class Arrow extends React.Component {
    constructor(props) {
        super(props);
        this.state = {hover: false};
    }

    shouldComponentUpdate(nextProps, nextState) {
        if (this.props.color === this.props.colorHover && this.props.background === this.props.backgroundHover && this.state.hover === nextState.hover && this.props.direction === nextProps.direction) {
            return false;
        }
        return true;
    }

    hover() {
        this.setState({hover: true});
    }
    leave() {
        this.setState({hover: false});
    }

    render () {
        const degrees = this.props.direction === 'right' ? 180 : this.props.direction === 'top' ? 90 : this.props.direction === 'bottom' ? -90 : 0;

        return (
            <div style={{height: this.props.height}}
                 onMouseEnter={() => this.props.disableHover ? null : this.hover()}
                 onMouseLeave={() =>  this.props.disableHover ? null : this.leave()}
                 onClick={() => this.props.onClick()}
            >
                {this.props.text !== '' ?
                    <span style={{color: this.state.hover ? this.props.colorHover : this.props.color}}>{this.props.text}</span>
                    :
                    null
                }
                <svg viewBox="0 0 451.8 451.8"
                     style={{
                         ...{
                             cursor: 'pointer',
                             backgroundColor: this.state.hover ? this.props.backgroundHover : this.props.background,
                             width: this.props.width,
                             height: this.props.height,
                             transform: 'rotate(' + degrees + 'deg)'
                         }, ...this.props.style
                     }}
                >
                    <path d="M97.1 225.9c0-8.1 3.1-16.2 9.3-22.4L300.7 9.3c12.4-12.4 32.4-12.4 44.8 0 12.4 12.4 12.4 32.4 0 44.7L173.5 225.9l171.9 171.9c12.4 12.4 12.4 32.4 0 44.7 -12.4 12.4-32.4 12.4-44.7 0L106.4 248.3C100.2 242.1 97.1 234 97.1 225.9z"
                          fill={this.state.hover ? this.props.colorHover : this.props.color}/>
                </svg>
            </div>
        )
    }

};

Arrow.defaultProps  = {
    onClick: function () {},
    color: 'black',
    text: '',
    colorHover: 'black',
    background: 'transparent',
    backgroundHover: 'transparent',
    width: '100%',
    height: 'auto',
    direction: 'left',
    style: {},
    disableHover: isTouch(),
};

Arrow.propTypes = {
    onClick: PropTypes.func,
    color: PropTypes.string,
    colorHover: PropTypes.string,
    background: PropTypes.string,
    backgroundHover: PropTypes.string,
    width: PropTypes.string,
    height: PropTypes.string,
    direction: PropTypes.string,
    text: PropTypes.string,
    style: PropTypes.object,
    disableHover: PropTypes.bool,
};

module.exports = Arrow;
