import React from 'react';
import PropTypes from 'prop-types';
import {isTouch} from './utils';

class Home extends React.Component {
    constructor(props) {
        super(props);
        this.state = {hover: false};
    }

    shouldComponentUpdate(nextProps, nextState) {
        if (this.props.color === this.props.colorHover && this.props.background === this.props.backgroundHover && this.props.color === nextProps.color && this.state.hover === nextState.hover) {
            return false;
        }
        return true;
    }

    hover() {
            this.setState({hover: true});
    }
    leave() {
        this.setState({hover: false});
    }

    render () {
        return (
            <div style={{position: 'relative',  height: this.props.height, cursor: 'pointer'}}
                 onMouseEnter={() => this.props.disableHover ? null : this.hover()}
                 onMouseLeave={() =>  this.props.disableHover ? null : this.leave()}
                 onClick={() => this.props.onClick()}
            >
                <svg viewBox="0 0 512 512"
                     style={{
                         ...{
                         width: this.props.width,
                         height: this.props.height,
                         backgroundColor: this.state.hover || this.props.active ? this.props.backgroundHover : this.props.background},...this.props.style
                     }}

                >
                    <path d="M506.6 208.1L263.9 30.4c-4.7-3.4-11-3.4-15.7 0L5.4 208.1c-5.9 4.3-7.2 12.7-2.9 18.6s12.7 7.2 18.6 2.9L256 57.6l234.8 171.9c2.4 1.7 5.1 2.6 7.8 2.6 4.1 0 8.1-1.9 10.7-5.4C513.8 220.7 512.5 212.4 506.6 208.1z"
                          fill={this.state.hover || this.props.active ? this.props.colorHover : this.props.color}/>
                    <path d="M442.2 232.5c-7.3 0-13.3 6-13.3 13.3v211.7H322.5V342c0-36.7-29.8-66.5-66.5-66.5s-66.5 29.8-66.5 66.5v115.6H83.1V245.8c0-7.3-6-13.3-13.3-13.3s-13.3 6-13.3 13.3v225.1c0 7.3 6 13.3 13.3 13.3h133c7 0 12.7-5.4 13.3-12.3 0-0.3 0.1-0.7 0.1-1v-128.9c0-22 17.9-39.9 39.9-39.9s39.9 17.9 39.9 39.9v128.9c0 0.4 0 0.7 0.1 1 0.5 6.9 6.3 12.3 13.3 12.3h133c7.3 0 13.3-6 13.3-13.3V245.8C455.5 238.5 449.6 232.5 442.2 232.5z"
                          fill={this.state.hover || this.props.active ? this.props.colorHover : this.props.color}/>
                </svg>
                {this.props.underline && (this.state.hover || this.props.active) ?
                    <span style={{width: '10px', height: '3px', position: 'absolute', bottom: '0', right: '0', left: '0', margin: '0 auto', background: this.props.colorHover}}/>
                    :
                    null
                }
            </div>
        )
    }

};

Home.defaultProps  = {
    onClick: function () {},
    color: 'black',
    colorHover: 'red',
    background: 'transparent',
    backgroundHover: 'transparent',
    width: '100%',
    height: '100%',
    underline: false,
    active: false,
    disableHover: isTouch(),
    style: {}
};

Home.propTypes = {
    onClick: PropTypes.func,
    color: PropTypes.string,
    colorHover: PropTypes.string,
    background: PropTypes.string,
    backgroundHover: PropTypes.string,
    width: PropTypes.string,
    height: PropTypes.string,
    underline: PropTypes.bool,
    active: PropTypes.bool,
    disableHover: PropTypes.bool,
    style: PropTypes.object,

};

module.exports = Home;
