import React from 'react';
import PropTypes from 'prop-types';
import {isTouch} from './utils';

class Information extends React.Component {
    constructor(props) {
        super(props);
        this.state = {hover: false};
    }

    shouldComponentUpdate(nextProps, nextState) {
        if (this.props.color === this.props.colorHover && this.props.background === this.props.backgroundHover && this.props.color === nextProps.color) {
            return false;
        }
        return true;
    }

    hover() {
        this.setState({hover: true});
    }
    leave() {
        this.setState({hover: false});
    }

    render () {
        return (
            <svg viewBox="0 0 330 330"
                 style={{...{
                     cursor: 'pointer',
                     backgroundColor: this.state.hover ? this.props.backgroundHover : this.props.background,
                     width: this.props.width,
                     boxSizing: 'border-box',
                     height: this.props.height
                 }, ...this.props.style
                 }}
                 onMouseEnter={() => this.props.disableHover ? null : this.hover()}
                 onMouseLeave={() =>  this.props.disableHover ? null : this.leave()}
                 onClick={() => this.props.onClick()}
            >
                <path d="M165 0C74 0 0 74 0 165 0 256 74 330 165 330s165-74 165-165C330 74 256 0 165 0zM165 300c-74.4 0-135-60.6-135-135C30 90.6 90.6 30 165 30s135 60.6 135 135C300 239.4 239.4 300 165 300z"
                      fill={this.state.hover ? this.props.colorHover : this.props.color}/>
                <path d="M165 70c-11 0-20 9-20 20 0 11 9 20 20 20 11 0 20-9 20-20C185 79 176 70 165 70z"
                      fill={this.state.hover ? this.props.colorHover : this.props.color}/>
                <path d="M165 140c-8.3 0-15 6.7-15 15v90c0 8.3 6.7 15 15 15 8.3 0 15-6.7 15-15v-90C180 146.7 173.3 140 165 140z"
                      fill={this.state.hover ? this.props.colorHover : this.props.color}/>
            </svg>
        )
    }

};

Information.defaultProps  = {
    onClick: function () {},
    color: 'black',
    style: {},
    colorHover: 'red',
    background: 'transparent',
    backgroundHover: 'transparent',
    width: '100%',
    height: '100%',
    disableHover: isTouch(),
};

Information.propTypes = {
    onClick: PropTypes.func,
    color: PropTypes.string,
    colorHover: PropTypes.string,
    background: PropTypes.string,
    backgroundHover: PropTypes.string,
    width: PropTypes.string,
    height: PropTypes.string,
    style: PropTypes.object,
    disableHover: PropTypes.bool,

};

module.exports = Information;
