import React from 'react';
import PropTypes from 'prop-types';
import debounce from 'lodash.debounce';

class Input extends React.Component {
    constructor(props) {
        super(props);
        this.state = {focus: false, value: props.value};
        this.changed = debounce(this.props.onChange, 250)
    }

    shouldComponentUpdate(nextProps, nextState) {
        if (
            this.props.color === this.props.colorHover &&
            this.props.background === this.props.backgroundHover &&
            this.props.color === nextProps.color &&
            this.state.value === nextState.value &&
            this.props.value === nextProps.value &&
            this.state.focus === nextState.focus
        ) {
            return false;
        }
        return true;
    }

    componentWillReceiveProps(nextProps, nextState) {
        if (this.props.debounce === true) {
            if (nextProps.value == '') {
                this.setState({value: nextProps.value});
            }
        }
    }

    focus() {
        this.setState({focus: true});
    }

    blur() {
        this.setState({focus: false});
    }

    handleChange = e => {
        const val = e.target.value
        if (this.props.debounce) {
            this.setState({value: val}, () => {
                this.changed(val)
            })
        } else {
            this.props.onChange(val);
        }
    }

    render () {
        const defaultStyles = {
            border: '1px solid',
            borderColor: this.state.focus ? this.props.borderActive : this.props.border,
            fontSize: 'inherit',
            color: 'inherit',
            fontFamily: 'inherit',
            borderRadius: 5,
            padding: '8px 12px',
            width: this.props.width,
            backgroundColor: 'transparent',
            height: this.props.height,
            outlineStyle: 'none',
            boxSizing: 'border-box',
            appearance: 'none',
            WebkitAppearance: 'none',
        };

        return (
            this.props.type === 'text' ?
                <input
                    onFocus={() => this.focus()}
                    onBlur={() => this.blur()}
                    onChange={this.handleChange}
                    style={{...defaultStyles, ...this.props.style}}
                    type="text"
                    maxLength={this.props.max}
                    value={this.props.debounce ? this.state.value : this.props.value}
                    placeholder={this.props.placeholder}
                />
                :
                this.props.type === 'number' ?
                    <input
                        onFocus={() => this.focus()}
                        onBlur={() => this.blur()}
                        onChange={(e) => this.props.onChange(e.target.value)}
                        style={{...defaultStyles, ...this.props.style}}
                        type="number"
                        min={this.props.min}
                        max={this.props.max}
                        value={this.props.value}
                    />
                    :
                    this.props.type === 'select' ?
                        <div style={{position: 'relative', zIndex: '1', width: '100%'}}>
                            <select
                                onFocus={() => this.focus()}
                                onBlur={() => this.blur()}
                                onChange={(e) => this.props.onChange(e.target.value)}
                                style={{...defaultStyles, ...this.props.style}}
                                value={this.props.value}>
                                {this.props.options.map(option => (
                                    <option key={option['id']} value={option['id']}>{option['name']}</option>
                                ))
                                }
                            </select>
                            <svg style={{
                                position: 'absolute',
                                top: '7px',
                                right: '5px',
                                zIndex:'-1'
                            }}
                                 fill="#acacac"
                                 height="24"
                                 viewBox="0 0 24 24"
                                 width="24">
                                <path d="M7 10l5 5 5-5z"
                                      fill={this.state.focus ? this.props.borderActive : this.props.border}/><path d="M0 0h24v24H0z" fill="none"/></svg>
                        </div>
                        :
                        <input
                            onFocus={() => this.focus()}
                            onBlur={() => this.blur()}
                            onChange={this.handleChange}
                            style={{...defaultStyles, ...this.props.style}}
                            type={this.props.type}
                            maxLength={this.props.max}
                            value={this.props.debounce ? this.state.value : this.props.value}
                            placeholder={this.props.placeholder}
                        />

        )
    }

};

Input.defaultProps  = {
    onChange: function () {},
    border: '#acacac',
    debounce: false,
    placeholder: '',
    borderActive: '#acacac',
    height: '40px',
    type: 'text',
    width: '100%',
    value: '',
    min: '0',
    max: '9999',
    style: {},
    options: [],
};

Input.propTypes = {
    onChange: PropTypes.func,
    border: PropTypes.string,
    borderActive: PropTypes.string,
    debounce: PropTypes.bool,
    height: PropTypes.string,
    type: PropTypes.string,
    width: PropTypes.string,
    value: PropTypes.string,
    placeholder: PropTypes.string,
    min: PropTypes.string,
    max: PropTypes.string,
    style: PropTypes.object,
    options: PropTypes.array,

};

module.exports = Input;
