import React from 'react';
import PropTypes from 'prop-types';
import {isTouch} from './utils';

class Question extends React.Component {
    constructor(props) {
        super(props);
        this.state = {hover: false};
    }

    shouldComponentUpdate(nextProps, nextState) {
        if (this.props.color === this.props.colorHover && this.props.background === this.props.backgroundHover && this.props.color === nextProps.color && this.state.hover === nextState.hover) {
            return false;
        }
        return true;
    }

    hover() {
        this.setState({hover: true});
    }
    leave() {
        this.setState({hover: false});
    }

    render () {
        return (
            <div
                onMouseEnter={() => this.props.disableHover ? null : this.hover()}
                onMouseLeave={() =>  this.props.disableHover ? null : this.leave()}
                onClick={() => this.props.onClick()}
                style={{...{display: 'flex', alignItems: 'center', cursor: 'pointer', color: this.state.hover ? this.props.colorHover : this.props.color},...this.props.style}}>
                <svg viewBox="-418 -29.8 226.8 226.8"
                     style={{
                         marginRight: '10px',
                         width: this.props.width,
                         height: this.props.height,
                     }}
                >
                    <path d="M-306.1-29.8c-62.6 0.8-112.7 52.3-111.9 114.9 0.8 62.6 52.3 112.7 114.9 111.9 62.6-0.8 112.7-52.3 111.9-114.9C-192.1 19.5-243.5-30.6-306.1-29.8zM-306.5 152.6l-0.6 0c-9.6-0.3-16.4-7.4-16.2-16.9 0.3-9.3 7.2-16.1 16.6-16.1l0.6 0c9.9 0.3 16.6 7.3 16.4 17.1C-290.1 146.1-296.9 152.6-306.5 152.6zM-265.9 72.1c-2.3 3.2-7.3 7.2-13.5 12.1l-6.9 4.8c-3.8 3-6.1 5.7-6.9 8.5 -0.7 2.2-1 2.7-1.1 7.1l0 1.1h-26.4l0.1-2.2c0.3-9.2 0.5-14.6 4.4-19.1 6-7 19.2-15.5 19.7-15.9 1.9-1.4 3.5-3 4.7-4.8 2.8-3.8 4-6.8 4-9.8 0-4.1-1.2-7.9-3.6-11.3 -2.3-3.3-6.7-4.9-13.1-4.9 -6.3 0-10.6 2-13.2 6.1 -2.7 4.2-4 8.7-4 13.2v1.1h-27.2l0-1.2c0.7-16.7 6.7-28.7 17.7-35.7 6.9-4.5 15.6-6.7 25.6-6.7 13.2 0 24.3 3.2 33.1 9.5 8.9 6.4 13.4 16 13.4 28.5C-259.3 59.6-261.5 66.1-265.9 72.1z"
                          fill={this.state.hover ? this.props.colorHover : this.props.color}/>
                </svg>
                {this.props.children}
            </div>
        )
    }

};

Question.defaultProps  = {
    onClick: function () {},
    children: '',
    color: 'black',
    colorHover: 'red',
    width: '100%',
    height: '100%',
    style: {},
    disableHover: isTouch(),
};

Question.propTypes = {
    onClick: PropTypes.func,
    color: PropTypes.string,
    colorHover: PropTypes.string,
    width: PropTypes.string,
    height: PropTypes.string,
    children: PropTypes.string,
    style: PropTypes.object,
    disableHover: PropTypes.bool,
};

module.exports = Question;
