import React from 'react';
import PropTypes from 'prop-types';
import {isTouch} from './utils';

class Search extends React.Component {
    constructor(props) {
        super(props);
        this.state = {hover: false};
    }

    shouldComponentUpdate(nextProps, nextState) {
        if (this.props.color === this.props.colorHover && this.props.background === this.props.backgroundHover && this.props.color === nextProps.color && this.state.hover === nextState.hover) {
            return false;
        }
        return true;
    }

    hover() {
        this.setState({hover: true});
    }
    leave() {
        this.setState({hover: false});
    }

    render () {
        return (
            <svg viewBox="0 0 475.1 475.1"
                 style={{...{
                     cursor: 'pointer',
                     backgroundColor: this.state.hover ? this.props.backgroundHover : this.props.background,
                     width: this.props.width,
                     boxSizing: 'border-box',
                     height: this.props.height
                 }, ...this.props.style
                 }}
                 onMouseEnter={() => this.props.disableHover ? null : this.hover()}
                 onMouseLeave={() =>  this.props.disableHover ? null : this.leave()}
                 onClick={() => this.props.onClick()}
            >
                <path d="M464.5 412.8l-97.9-97.9c23.6-34.1 35.4-72 35.4-113.9 0-27.2-5.3-53.2-15.9-78.1 -10.6-24.8-24.8-46.3-42.8-64.2 -18-18-39.4-32.3-64.2-42.8C254.2 5.3 228.2 0 201 0c-27.2 0-53.2 5.3-78.1 15.8C98.1 26.4 76.7 40.7 58.7 58.7c-18 18-32.3 39.4-42.8 64.2C5.3 147.8 0 173.8 0 201c0 27.2 5.3 53.2 15.8 78.1 10.6 24.8 24.8 46.2 42.8 64.2 18 18 39.4 32.3 64.2 42.8 24.8 10.6 50.9 15.8 78.1 15.8 41.9 0 79.9-11.8 113.9-35.4l97.9 97.6c6.9 7.2 15.4 10.8 25.7 10.8 9.9 0 18.5-3.6 25.7-10.8 7.2-7.2 10.8-15.8 10.8-25.7C475.1 428.5 471.6 419.9 464.5 412.8zM291.4 291.4c-25 25-55.1 37.5-90.4 37.5 -35.2 0-65.3-12.5-90.4-37.5 -25-25-37.5-55.1-37.5-90.4 0-35.2 12.5-65.3 37.5-90.4 25-25 55.2-37.5 90.4-37.5 35.2 0 65.3 12.5 90.4 37.5 25 25 37.5 55.2 37.5 90.4C328.9 236.2 316.4 266.3 291.4 291.4z"
                      fill={this.state.hover ? this.props.colorHover : this.props.color}/>
            </svg>
        )
    }

};

Search.defaultProps  = {
    onClick: function () {},
    color: 'black',
    style: {},
    colorHover: 'black',
    background: 'transparent',
    backgroundHover: 'transparent',
    width: '100%',
    height: '100%',
    disableHover: isTouch(),

};

Search.propTypes = {
    onClick: PropTypes.func,
    color: PropTypes.string,
    colorHover: PropTypes.string,
    background: PropTypes.string,
    backgroundHover: PropTypes.string,
    width: PropTypes.string,
    height: PropTypes.string,
    style: PropTypes.object,
    disableHover: PropTypes.bool,
};

module.exports = Search;
