import React from 'react';
import PropTypes from 'prop-types';
import {isTouch} from './utils';

class Text extends React.Component {
    constructor(props) {
        super(props);
        this.state = {hover: false};
    }

    shouldComponentUpdate(nextProps, nextState) {
        if (this.props.color === this.props.colorHover && this.props.background === this.props.backgroundHover && this.props.color === nextProps.color && this.state.hover === nextState.hover) {
            return false;
        }
        return true;
    }

    hover() {
        this.setState({hover: true});
    }
    leave() {
        this.setState({hover: false});
    }

    render () {
        return (
            <div
                onClick={() => this.props.onClick()}
                onMouseEnter={() => this.props.disableHover ? null : this.hover()}
                onMouseLeave={() =>  this.props.disableHover ? null : this.leave()}
                style={{ ...{display: 'flex', alignItems: 'center', justifyContent: 'center', cursor: 'pointer', position: 'relative', color: this.state.hover || this.props.active ? this.props.colorHover : this.props.color }, ...this.props.style }}>
                {this.props.children}
                {this.props.underline && (this.state.hover || this.props.active) ?
                    <span style={{width: this.props.underlineFull ? '100%' :'10px', height: '3px', position: 'absolute', bottom: '0', right: '0', left: '0', margin: '0 auto', background: this.props.colorHover}}/>
                    :
                    null
                }
            </div>
        )
    }

};

Text.defaultProps  = {
    onClick: function () {},
    color: 'inherit',
    colorHover: 'inherit',
    children: 'Click me',
    underline: false,
    active: false,
    underlineFull: false,
    style: {},
    disableHover: isTouch(),
};

Text.propTypes = {
    onClick: PropTypes.func,
    color: PropTypes.string,
    colorHover: PropTypes.string,
    children: PropTypes.string,
    underline: PropTypes.bool,
    active: PropTypes.bool,
    disableHover: PropTypes.bool,
    underlineFull: PropTypes.bool,
    style: PropTypes.object,
};

module.exports = Text;
