import React from 'react';
import { storiesOf, action, linkTo } from '@kadira/storybook';
import Button from './Button';
import Input from './Input';
import Close from './Close';
import Check from './Check';
import UserShape from './userShape';
import Lock from './lock';
import Search from './Search';
import Filter from './Filter';
import Information from './Information';
import Home from './Home';
import Text from './Text';
import Alert from './Alert';
import Arrow from './Arrow';
import Trophy from './Trophy';
import Warning from './Warning';
import Question from './Question';
import Welcome from './Welcome';
import GwMathes from './game/gwMatches';
import Modal from './modal';
import Loader from './Loader';

storiesOf('Welcome', module)
  .add('to Storybook', () => (
    <Welcome showApp={linkTo('Button')}/>
  ));

storiesOf('Button', module)
  .add('Button', () => (
      <div>
        <div>
          children: button text (string)<br/>
          onClick: function (func)<br/>
          filled: is fill or transparent (bool)<br/>
          lighten: if filled true on hover lighten or darker (bool)<br/>
          small: size (bool)<br/>
          medium: size (bool)<br/>
          big: size (bool)<br/>
          disabled: disabled false (bool)<br/>
          color: color on hover border or background color if filled (string)<br/>
          border: border color if not filled (string)<br/>
          style: custom styles (object)<br/>
          type: html type attr (bool)<br/>
          icon: plus, arrowRight, share (string)<br/>
        </div>
        <div>
          <Button big onClick={action('clicked')} color="#ff9800" filled >big</Button>
          <Button medium onClick={action('clicked')} color="#ff9800" filled >medium</Button>
          <Button small onClick={action('clicked')} color="#ff9800" filled >small</Button>
          <Button disabled small onClick={action('clicked')} color="#ff9800" filled >disabled</Button>
        </div>
        <div>
          <Button big onClick={action('clicked')} color="#ff9800" >big</Button>
          <Button medium onClick={action('clicked')} color="#ff9800" >medium</Button>
          <Button small onClick={action('clicked')} color="#ff9800" >small</Button>
          <Button disabled small onClick={action('clicked')} color="#ff9800" >disabled</Button>
        </div>
        <div>
          <Button big icon='plus' onClick={action('clicked')} color="#ff9800" >big</Button>
          <Button medium icon='plus' onClick={action('clicked')} color="#ff9800" >medium</Button>
          <Button small icon='plus' onClick={action('clicked')} color="#ff9800" >small</Button>
          <Button disabled icon='plus' small onClick={action('clicked')} color="#ff9800" >disabled</Button>
        </div>
          <div>
              <Button big icon='plus' onClick={action('clicked')} color="#ff9800" filled >big</Button>
              <Button medium icon='plus' onClick={action('clicked')} color="#ff9800" filled >medium</Button>
              <Button small icon='plus' onClick={action('clicked')} color="#ff9800" filled >small</Button>
              <Button disabled icon='plus' small onClick={action('clicked')} color="#ff9800" filled >disabled</Button>
          </div>
        <div>
          <Button big icon='arrowRight' onClick={action('clicked')} color="#ff9800" >big</Button>
          <Button medium icon='arrowRight' onClick={action('clicked')} color="#ff9800" >medium</Button>
          <Button small icon='arrowRight' onClick={action('clicked')} color="#ff9800" >small</Button>
          <Button disabled icon='arrowRight' small onClick={action('clicked')} color="#ff9800" >disabled</Button>
        </div>
          <div>
              <Button big icon='arrowRight' onClick={action('clicked')} color="#ff9800" filled >big</Button>
              <Button medium icon='arrowRight' onClick={action('clicked')} color="#ff9800" filled >medium</Button>
              <Button small icon='arrowRight' onClick={action('clicked')} color="#ff9800" filled >small</Button>
              <Button disabled icon='arrowRight' small onClick={action('clicked')} color="#ff9800" filled >disabled</Button>
          </div>
        <div>
          <Button big icon='share' onClick={action('clicked')} color="#ff9800" >big</Button>
          <Button medium icon='share' onClick={action('clicked')} color="#ff9800" >medium</Button>
          <Button small icon='share' onClick={action('clicked')} color="#ff9800" >small</Button>
          <Button disabled icon='arrowRight' small onClick={action('clicked')} color="#ff9800" >disabled</Button>
        </div>
          <div>
              <Button big icon='share' onClick={action('clicked')} color="#ff9800" filled >big</Button>
              <Button medium icon='share' onClick={action('clicked')} color="#ff9800" filled >medium</Button>
              <Button small icon='share' onClick={action('clicked')} color="#ff9800" filled >small</Button>
              <Button disabled icon='share' small onClick={action('clicked')} color="#ff9800" filled >disabled</Button>
          </div>
      </div>
  ))

storiesOf('Input', module)
  .add('text', () => (
      <div>
        <div>
          borderActive: border active color (string)<br/>
          border: border color (string)<br/>
          width: width (string)<br/>
          height: width (height)<br/>
          style: custom styles (object)<br/>
          onChange: function (func)<br/>
          max: max characters (string)<br/>
          value: value (string)<br/>
        </div>
        <div>
          <Input type="text" onChange={action('changed')} border="#ff9800"  borderActive="red" value="need onchange action to change value"/><br/>
        </div>
      </div>
  ))
  .add('select', () => (
      <div>
        <div>
            borderActive: border active color (string)<br/>
            border: border color (string)<br/>
            width: width (string)<br/>
            height: width (height)<br/>
            style: custom styles (object)<br/>
            onChange: function (func)<br/>
            value: value (string)<br/>
            options: id is value name is text (array)<br/>
        </div>
        <div>
          <Input onChange={action('changed')} type="select" border="#ff9800"  borderActive="red" value="1" options={[{id:1, name: 'test'}, {id:2, name: 'test 2'}]}/><br/>
        </div>
      </div>
  ))
  .add('number', () => (
      <div>
        <div>
            borderActive: border active color (string)<br/>
            border: border color (string)<br/>
            width: width (string)<br/>
            height: width (height)<br/>
            style: custom styles (object)<br/>
            onChange: function (func)<br/>
            max: max number (string)<br/>
            min: min number (string)<br/>
            value: value (string)<br/>
        </div>
        <div>
            <Input onChange={action('changed')} type="number" onClick={action('clicked')} border="#ff9800"  borderActive="red" value="1" min="0" max="5"/><br/>
        </div>
      </div>
  ))

storiesOf('SVG icons', module)
  .add('Close', () => (
  <div>
      <div>
          colorHover: color hover (string)<br/>
          color: color initial (string)<br/>
          background: background initial (string)<br/>
          backgroundHover: background hover (string)<br/>
          width: width (string)<br/>
          height: width (height)<br/>
          style: custom styles (object)<br/>
          onClick: function (func)<br/>
      </div>
      <div>
          <Close width="100px" onClick={action('clicked')} color="black" colorHover="#ff9800"/>
      </div>
  </div>
  ))
  .add('Check', () => (
  <div>
      <div>
          colorHover: color hover (string)<br/>
          color: color initial (string)<br/>
          background: background initial (string)<br/>
          backgroundHover: background hover (string)<br/>
          width: width (string)<br/>
          height: width (height)<br/>
          style: custom styles (object)<br/>
          onClick: function (func)<br/>
      </div>
      <div>
          <Check width="100px" onClick={action('clicked')} />
      </div>
  </div>
  ))
  .add('User shape', () => (
  <div>
      <div>
          colorHover: color hover (string)<br/>
          color: color initial (string)<br/>
          width: width (string)<br/>
          height: width (height)<br/>
          style: custom styles (object)<br/>
          onClick: function (func)<br/>
          disableHover: false bool<br/>
          pointer: false (bool)<br/>
      </div>
      <div>
          <UserShape width="100px" color="red" onClick={action('clicked')} />
      </div>
  </div>
  ))
  .add('Lock', () => (
  <div>
      <div>
          colorHover: color hover (string)<br/>
          color: color initial (string)<br/>
          width: width (string)<br/>
          height: width (height)<br/>
          style: custom styles (object)<br/>
          onClick: function (func)<br/>
          disableHover: false bool<br/>
          pointer: false (bool)<br/>
      </div>
      <div>
          <Lock unlock width="100px" color="red" onClick={action('clicked')} />
          <Lock unlockHalf width="100px" color="red" onClick={action('clicked')} />
          <Lock width="100px" color="red" onClick={action('clicked')} />
      </div>
  </div>
  ))
  .add('Search', () => (
  <div>
      <div>
          colorHover: color hover (string)<br/>
          color: color initial (string)<br/>
          background: background initial (string)<br/>
          backgroundHover: background hover (string)<br/>
          width: width (string)<br/>
          height: width (height)<br/>
          style: custom styles (object)<br/>
          onClick: function (func)<br/>
      </div>
      <div>
          <Search onClick={action('clicked')} color="black" colorHover="#ff9800"  width="100px"/>
      </div>
  </div>
  ))
  .add('Filter', () => (
  <div>
      <div>
          colorHover: color hover (string)<br/>
          color: color initial (string)<br/>
          background: background initial (string)<br/>
          backgroundHover: background hover (string)<br/>
          width: width (string)<br/>
          height: width (height)<br/>
          style: custom styles (object)<br/>
          onClick: function (func)<br/>
      </div>
      <div>
          <Filter onClick={action('clicked')} color="black" colorHover="#ff9800"  width="100px"/>
      </div>
  </div>
  ))
  .add('Information', () => (
  <div>
      <div>
          colorHover: color hover (string)<br/>
          color: color initial (string)<br/>
          background: background initial (string)<br/>
          backgroundHover: background hover (string)<br/>
          width: width (string)<br/>
          height: width (height)<br/>
          style: custom styles (object)<br/>
          onClick: function (func)<br/>
      </div>
      <div>
          <Information onClick={action('clicked')} color="black" colorHover="#ff9800"  width="100px"/>
      </div>
  </div>
  ))
  .add('Home', () => (
  <div>
      <div>
          colorHover: color hover (string)<br/>
          color: color initial (string)<br/>
          background: background initial (string)<br/>
          backgroundHover: background hover (string)<br/>
          width: width (string)<br/>
          height: width (height)<br/>
          style: custom styles (object)<br/>
          onClick: function (func)<br/>
          active: is active (bool)<br/>
          underline: has underline (bool)<br/>
      </div>
      <div>
          <Home underline onClick={action('clicked')} color="black" colorHover="#ff9800"  width="100px"/>
      </div>
  </div>
  ))
  .add('Trophy', () => (
  <div>
      <div>
          color: color initial (string)<br/>
          width: width (string)<br/>
          height: width (height)<br/>
          style: custom styles (object)<br/>
      </div>
      <div>
          <Trophy color="red"  width="100px"/>
      </div>
  </div>
  ))
  .add('Warning', () => (
  <div>
      <div>
          color: color initial (string)<br/>
          width: width (string)<br/>
          height: width (height)<br/>
          style: custom styles (object)<br/>
      </div>
      <div>
          <Warning color="red"  width="100px"/>
      </div>
  </div>
  ))
  .add('Question', () => (
  <div>
      <div>
          colorHover: color hover (string)<br/>
          color: color initial (string)<br/>
          background: background initial (string)<br/>
          backgroundHover: background hover (string)<br/>
          width: width (string)<br/>
          height: width (height)<br/>
          style: custom styles (object)<br/>
          onClick: function (func)<br/>
          children: text near (string)<br/>
      </div>
      <div>
          <Question style={{marginTop: '25px'}} onClick={action('clicked')} color="black" colorHover="#ff9800"  width="100px">HOW TO PLAY</Question>
      </div>
  </div>
  ))
  .add('Arrow', () => (
  <div>
      <div>
          colorHover: color hover (string)<br/>
          color: color initial (string)<br/>
          background: background initial (string)<br/>
          backgroundHover: background hover (string)<br/>
          width: width (string)<br/>
          height: width (height)<br/>
          style: custom styles (object)<br/>
          onClick: function (func)<br/>
          text: text near (string)<br/>
          direction: top, left, right, bottom (string)<br/>
      </div>
      <div>
          <Arrow onClick={action('clicked')} color="black" colorHover="#ff9800" direction="left" width="100px"/>
          <Arrow onClick={action('clicked')} color="black" colorHover="#ff9800" direction="top" width="100px"/>
          <Arrow onClick={action('clicked')} color="black" colorHover="#ff9800" direction="right" width="100px"/>
          <Arrow onClick={action('clicked')} color="black" colorHover="#ff9800" direction="bottom" width="100px"/>
      </div>
  </div>
  ))

storiesOf('TEXT', module)
    .add('Text', () => (
        <div>
            <div>
                colorHover: color hover (string)<br/>
                color: color initial (string)<br/>
                colorHover: color hover (string)<br/>
                background: background initial (string)<br/>
                backgroundHover: background hover (string)<br/>
                width: width (string)<br/>
                height: width (height)<br/>
                style: custom styles (object)<br/>
                onClick: function (func)<br/>
                active: is active (bool)<br/>
                underline: has underline (bool)<br/>
            </div>
            <div>
                <Text underline onClick={action('clicked')} color="black" colorHover="#ff9800"  width="100px">CLICK ME</Text>
            </div>
        </div>
    ))
    .add('Alert', () => (
        <div>
            <div>
                colorHover: color hover (string)<br/>
                color: color initial (string)<br/>
                colorHover: color hover (string)<br/>
                background: background initial (string)<br/>
                backgroundHover: background hover (string)<br/>
                width: width (string)<br/>
                height: width (height)<br/>
                style: custom styles (object)<br/>
                onClick: function (func)<br/>
                active: is active (bool)<br/>
                underline: has underline (bool)<br/>
            </div>
            <div>
                <Alert  onClick={action('clicked alert')} success data={[{text : 'asd'}, {text: 'qqq'}]}/>
            </div>
        </div>
    ))

storiesOf('GAME', module)
    .add('Game week matches', () => (
        <div>
            <div>
                colorHover: color hover (string)<br/>
                color: color initial (string)<br/>
                colorHover: color hover (string)<br/>
                background: background initial (string)<br/>
                backgroundHover: background hover (string)<br/>
                width: width (string)<br/>
                height: width (height)<br/>
                style: custom styles (object)<br/>
                onClick: function (func)<br/>
                active: is active (bool)<br/>
                underline: has underline (bool)<br/>
            </div>
            <div>
                <GwMathes color="#ff9800"/>
            </div>
        </div>
    ))

storiesOf('Modal', module)
    .add('modal', () => (
        <div>
            <div>
                <Modal remove={action('close modal')} roundCorners shadow>
                    <div>
                        children: {},
                        remove: function () {},
                        close: true
                    </div>
                </Modal>
            </div>
        </div>
    ))
    .add('modal extra params', () => (
        <div>
            <div>
                <Modal remove={action('close modal')} closeColor="#D01C70" closeWidth="20px" closeThin maxWidth="660px">
                    <div>
                        children: {},
                        remove: function () {},
                        close: true
                    </div>
                </Modal>
            </div>
        </div>
    ))

storiesOf('Loader', module)
    .add('Loader', () => (
        <div>
            <div>
                <Loader/>
            </div>
        </div>
    ))


