import React from 'react';
import PropTypes from 'prop-types';
import {isTouch} from './utils';

class UserShape extends React.Component {
    constructor(props) {
        super(props);
        this.state = {hover: false};
    }

    shouldComponentUpdate(nextProps, nextState) {
        if (this.props.color === this.props.colorHover && this.props.color === nextProps.color && this.state.hover === nextState.hover) {
            return false;
        }
        return true;
    }

    hover() {
        this.setState({hover: true});
    }
    leave() {
        this.setState({hover: false});
    }

    render () {
        return (
            <svg viewBox="0 0 438.5 438.5"
                 style={{...{
                     cursor: this.props.pointer ? 'pointer' : 'default',
                     width: this.props.width,
                     boxSizing: 'border-box',
                     height: this.props.height
                 }, ...this.props.style
                 }}
                 onMouseEnter={() => this.props.disableHover ? null : this.hover()}
                 onMouseLeave={() =>  this.props.disableHover ? null : this.leave()}
                 onClick={() => this.props.onClick()}
            >
                <path d="M219.3 219.3c30.3 0 56.1-10.7 77.5-32.1 21.4-21.4 32.1-47.2 32.1-77.5 0-30.3-10.7-56.1-32.1-77.5C275.4 10.7 249.5 0 219.3 0S163.2 10.7 141.8 32.1c-21.4 21.4-32.1 47.3-32.1 77.5 0 30.3 10.7 56.1 32.1 77.5C163.2 208.6 189 219.3 219.3 219.3z"
                      fill={this.state.hover ? this.props.colorHover : this.props.color}/>
                <path d="M419.3 335c-0.7-9.6-2-20-4-31.1 -2-11.1-4.5-21.5-7.6-31 -3-9.5-7.1-18.8-12.3-27.8 -5.1-9-11-16.7-17.7-23.1 -6.7-6.4-14.8-11.5-24.4-15.3 -9.6-3.8-20.2-5.7-31.8-5.7 -1.7 0-5.7 2-12 6.1 -6.3 4.1-13.4 8.7-21.3 13.7 -7.9 5-18.2 9.6-30.8 13.7 -12.7 4.1-25.4 6.1-38.1 6.1 -12.8 0-25.5-2-38.1-6.1 -12.7-4.1-22.9-8.7-30.8-13.7 -7.9-5-15-9.6-21.3-13.7 -6.3-4.1-10.3-6.1-12-6.1 -11.6 0-22.2 1.9-31.8 5.7 -9.6 3.8-17.7 8.9-24.4 15.3 -6.7 6.4-12.6 14.1-17.7 23.1 -5.1 9-9.2 18.3-12.3 27.8 -3 9.5-5.6 19.8-7.6 31 -2 11.1-3.3 21.5-4 31.1 -0.7 9.6-1 19.5-1 29.6 0 22.8 6.9 40.9 20.8 54.1 13.9 13.2 32.4 19.8 55.4 19.8h249.5c23 0 41.5-6.6 55.4-19.8 13.9-13.2 20.8-31.3 20.8-54.1C420.3 354.5 419.9 344.7 419.3 335z"
                      fill={this.state.hover ? this.props.colorHover : this.props.color}/>/>
            </svg>
        )
    }

};

UserShape.defaultProps  = {
    onClick: function () {},
    color: 'black',
    style: {},
    colorHover: 'black',
    width: '100%',
    height: '100%',
    disableHover: isTouch(),
    pointer: false

};

UserShape.propTypes = {
    onClick: PropTypes.func,
    color: PropTypes.string,
    colorHover: PropTypes.string,
    width: PropTypes.string,
    height: PropTypes.string,
    style: PropTypes.object,
    disableHover: PropTypes.bool,
    pointer: PropTypes.bool,
};

module.exports = UserShape;
